import * as iam from 'aws-cdk-lib/aws-iam';
import * as lambda from 'aws-cdk-lib/aws-lambda';
import * as sfn from 'aws-cdk-lib/aws-stepfunctions';
import { Construct } from 'constructs';
export interface SearchablePDFProps {
    /** memory of Lambda function (may need to increase for larger documents) */
    readonly lambdaMemoryMB?: number;
    readonly lambdaTimeout?: number;
    readonly searchablePDFFunction?: lambda.IFunction;
    readonly s3TextractOutputBucket?: string;
    readonly s3PDFBucket?: string;
    /** prefix for the incoming document. Will be used to create role */
    readonly s3InputPrefix?: string;
    /** List of PolicyStatements to attach to the Lambda function for S3 GET and LIST. */
    readonly inputPolicyStatements?: iam.PolicyStatement[];
}
/**
 * This construct takes in a JSON with two s3 Paths, s3TextractOutput, s3PDFBucket
 *
 * example s3Path:
 * {"s3TextractOutput": "s3://bucketname/prefix/1"}
 * {"s3PDFBucket": "s3://bucketname/prefix/document.pdf"}
  ```

 *
 */
export declare class SearchablePDF extends sfn.StateMachineFragment {
    readonly startState: sfn.State;
    readonly endStates: sfn.INextable[];
    readonly searchablePDFFunction: lambda.IFunction;
    constructor(parent: Construct, id: string, props: SearchablePDFProps);
}
